==> sqlitestudio-3.0.7.tar.gz: Plugins/CsvImport/CsvImport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Impossible de lire le fichier %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Impossible de trouver des données dans le fichier %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="167"/>
        <source>Enter the custom separator character.</source>
        <translation>Saisir le caractère séparateur.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="181"/>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation>Saisir la valeur qui sera interprétée comme NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="194"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>Fichiers CSV (*.csv);;Fichiers texte (*.txt);;Tous les fichiers (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (virgule)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (point virgule)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (tab)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>(Espace)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Personalisé:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Ceci est possible si la permière ligne de votre fichier CSV représente le nom des colonnes.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip first row of data</source>
        <translation type="obsolete">Aller à la première ligne de données</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Champ séparateur:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>NULL values:</source>
        <translation>Valeurs  NULL:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="95"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Si votre CSV de données contient des valeurs nulles, définissez leur représentation dans le CSV.</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/CsvImport/CsvImport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Impossible de lire le fichier %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Impossible de trouver des données dans le fichier %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="163"/>
        <source>Enter the custom separator character.</source>
        <translation>Saisir le caractère séparateur.</translation>
    </message>
    <message>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation type="obsolete">Saisir la valeur qui sera interprétée comme NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="186"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>Fichiers CSV (*.csv);;Fichiers texte (*.txt);;Tous les fichiers (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (virgule)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (point virgule)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (tab)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>  (Espace)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Personalisé:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Ceci est possible si la permière ligne de votre fichier CSV représente le nom des colonnes.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip first row of data</source>
        <translation type="obsolete">Aller à la première ligne de données</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Champ séparateur:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>If enabled, then text value provided on the right will be interpreted as NULL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="88"/>
        <source>NULL values:</source>
        <translation>Valeurs NULL:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="98"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Si votre CSV de données contient des valeurs nulles, définissez leur représentation dans le CSV.</translation>
    </message>
</context>
</TS>
